@@ -65,8 +65,7 @@ def strip_comments(line: str) -> str:
 
     :return: Stripped line.
     """
-    res = COMMENT_RE.search(line)
-    if res:
+    if res := COMMENT_RE.search(line):
         line = line[: res.start()]
     return line.strip()
 
@@ -189,7 +188,7 @@ def parse_feature(basedir: str, filename: str, encoding: str = "utf-8") -> Featu
             scenario.examples.set_param_names([l for l in split_line(parsed_line) if l])
             mode = types.EXAMPLE_LINE
         elif mode == types.EXAMPLE_LINE:
-            scenario.examples.add_example([l for l in split_line(stripped_line)])
+            scenario.examples.add_example(list(split_line(stripped_line)))
         elif mode and mode not in (types.FEATURE, types.TAG):
             step = Step(name=parsed_line, type=mode, indent=line_indent, line_number=line_number, keyword=keyword)
             if feature.background and not scenario:
@@ -203,7 +202,7 @@ def parse_feature(basedir: str, filename: str, encoding: str = "utf-8") -> Featu
     return feature
 
 
-@dataclass
+@dataclass(eq=False)
 class Feature:
     scenarios: OrderedDict[str, ScenarioTemplate]
     filename: str
@@ -215,7 +214,7 @@ class Feature:
     description: str
 
 
-@dataclass
+@dataclass(eq=False)
 class ScenarioTemplate:
     """A scenario template.
 
@@ -279,7 +278,7 @@ class ScenarioTemplate:
         return "\n".join(self._description_lines)
 
 
-@dataclass
+@dataclass(eq=False)
 class Scenario:
     feature: Feature
     name: str
@@ -289,7 +288,7 @@ class Scenario:
     description: list[str] = field(default_factory=list)
 
 
-@dataclass
+@dataclass(eq=False)
 class Step:
     type: str
     _name: str
@@ -366,7 +365,7 @@ class Step:
         return STEP_PARAM_RE.sub(replacer, self.name)
 
 
-@dataclass
+@dataclass(eq=False)
 class Background:
     feature: Feature
     line_number: int
@@ -378,7 +377,7 @@ class Background:
         self.steps.append(step)
 
 
-@dataclass
+@dataclass(eq=False)
 class Examples:
     """Example table."""
 
