@@ -1,4 +1,5 @@
 """Step parsers."""
+
 from __future__ import annotations
 
 import abc
@@ -42,14 +43,14 @@ class re(StepParser):
 
         :return: `dict` of step arguments
         """
-        match = self.regex.match(name)
+        match = self.regex.fullmatch(name)
         if match is None:
             return None
         return match.groupdict()
 
     def is_matching(self, name: str) -> bool:
         """Match given name with the step name."""
-        return bool(self.regex.match(name))
+        return bool(self.regex.fullmatch(name))
 
 
 class parse(StepParser):
@@ -103,13 +104,11 @@ TStepParser = TypeVar("TStepParser", bound=StepParser)
 
 
 @overload
-def get_parser(step_name: str) -> string:
-    ...
+def get_parser(step_name: str) -> string: ...
 
 
 @overload
-def get_parser(step_name: TStepParser) -> TStepParser:
-    ...
+def get_parser(step_name: TStepParser) -> TStepParser: ...
 
 
 def get_parser(step_name: str | StepParser) -> StepParser:
