@@ -1,4 +1,5 @@
 """Various utility functions."""
+
 from __future__ import annotations
 
 import base64
@@ -19,7 +20,7 @@ T = TypeVar("T")
 CONFIG_STACK: list[Config] = []
 
 
-def get_args(func: Callable) -> list[str]:
+def get_args(func: Callable[..., Any]) -> list[str]:
     """Get a list of argument names for a function.
 
     :param func: The function to inspect.
